@@ -4,7 +4,7 @@
 
 add_header_proc do
   <<-EOS
-<script src="https://cdn.rawgit.com/google/code-prettify/master/loader/run_prettify.js"></script>
+<script src="https://cdn.jsdelivr.net/gh/google/code-prettify/loader/run_prettify.js"></script>
 EOS
 end
 
