@@ -8,10 +8,23 @@
 # Copyright (C) TADA Tadashi <t@tdtds.jp>
 # Distributed under GPL.
 #
+
+def rubykaigi2015( role = 'attendee', size = nil )
+	r = role.split(/[ _]+/).join('-')
+	s = "-@#{h size}" unless size.nil? || size == "1x"
+	%Q|<a href="http://rubykaigi.org/2015/" style="display:block;margin:8px auto;text-align:center;"><img src="http://rubykaigi.org/2015/images/goodies/banner-160-#{h r}#{s}.png" alt="RubyKaigi 2015 #{h r}"></a>|
+end
+
+def rubykaigi2014( role = 'attendee', size = nil )
+	r = role.split(/[ _]+/).join('-')
+	s = "@#{h size}" unless size.nil?
+	%Q|<a href="http://rubykaigi.org/2014/" style="display:block;margin:8px auto;text-align:center;"><img src="http://rubykaigi.org/2014/images/badge-for-#{h r}#{s}.png" alt="RubyKaigi 2014 #{h r}"></a>|
+end
+
 def rubykaigi2013( role = 'attendee', size = nil )
 	r = role.split(/[ _]+/).map{|s| s.capitalize}.join
 	s = "@#{h size}" unless size.nil?
-	%Q|<a href="http://rubykaigi.org/2013/" style="display:block;margin:8px auto;text-align:center;"><img src="http://rubykaigi.org/2013/badge#{h r}#{s}.png" alt="RubyKaigi 2013 #{h r}"></a>|
+	%Q|<a href="http://rubykaigi.org/2013/" style="display:block;margin:8px auto;text-align:center;"><img src="http://rubykaigi.org/2013/images/badge#{h r}#{s}.png" alt="RubyKaigi 2013 #{h r}"></a>|
 end
 
 def sappororubykaigi2012( role = 'attendee' )
@@ -45,7 +58,7 @@ def rubykaigi2011( role = 'attendee', size = 'large' )
 	%Q|<a href="http://rubykaigi.org/2011/" style="display:block;margin:8px auto;text-align:center;"><img src="http://rubykaigi.org/2011/goodies/badges/#{width}x#{height}#{badges[role]}.png" width="#{width}" height="#{height}" alt="RubyKaigi2010 #{h role.capitalize}" style="border-width: 0px;"></a>|
 end
 
-alias :rubykaigi :rubykaigi2011
+alias :rubykaigi :rubykaigi2015
 
 #----- OLD EDITIONS -----#
 
@@ -82,7 +95,7 @@ def rubykaigi2008( role = 'attendee' )
 		role = 'attendee'
 		0
 	end
-	%Q|<div style="text-align: center; margin-top: 0.5em; margin-bottom: 0.5em;"><a href="http://jp.rubyist.net/RubyKaigi2008/"><img src="http://rubykaigi.tdiary.net/images/20080617_#{img}.png" width="160" height="79" alt="RubyKaigi2008#{h role.capitalize}" style="border-width: 0px;"></a></div>|
+	%Q|<div style="text-align: center; margin-top: 0.5em; margin-bottom: 0.5em;"><a href="http://jp.rubyist.net/RubyKaigi2008/"><img src="http://userimages.tdiary.net/rubykaigi/20080617_#{img}.png" width="160" height="79" alt="RubyKaigi2008#{h role.capitalize}" style="border-width: 0px;"></a></div>|
 end
 
 def sappororubykaigi02( role = 'attendee' )
